@@ -1,5 +1,5 @@
 import requests
-from . import emoji
+from . import emoji, add_chat
 from ._base_url import BASE_URL
 
 
@@ -8,7 +8,11 @@ def get_message(chat_id: int, key: str) -> str:
         "chat_id": chat_id,
         "key": key
     })
-    message = r.json()['message']
+    try:
+        message = r.json()["message"]
+    except KeyError:
+        add_chat(chat_id, "en")
+        message = r.json()["message"]
     return message
 
 
